@@ -1223,14 +1223,16 @@ test_stochastic_weibull_impl(double lambda, double k)
     .k = k,
   };
 
+// clang-format off
 /*
  * XXX Consider applying a Tiku-Singh test:
  *
  *    M.L. Tiku and M. Singh, `Testing the two-parameter
  *    Weibull distribution', Communications in Statistics --
  *    Theory and Methods A10(9), 1981, 907--918.
- *https://www.tandfonline.com/doi/pdf/10.1080/03610928108828082?needAccess=true
+https://www.tandfonline.com/doi/pdf/10.1080/03610928108828082?needAccess=true
  */
+// clang-format on
   return test_psi_dist_sample(&dist.base);
 }
 
